# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"chi": "00_core.ipynb",
         "time_from_wrf": "00_core.ipynb",
         "coords_from_wrf": "00_core.ipynb",
         "chi_from_wrf": "00_core.ipynb",
         "wrf2msg": "00_core.ipynb",
         "load_table": "fwie.ipynb",
         "FWIe_calc": "fwie.ipynb"}

modules = ["core.py",
           "fwie.py"]

doc_url = "https://mnpinto.github.io/fwie/"

git_url = "https://github.com/mnpinto/fwie/tree/master/"

def custom_doc_links(name): return None
